@@ -1,5 +1,5 @@
 class DFA:
-    def __init__(self, input_state = {}, initial_state = None, final_state = []):
+    def __init__(self, input_state={}, initial_state=None, final_state=[]):
         """
         Initializes a new DFA object.
 
@@ -38,17 +38,9 @@ class DFA:
             self.final_state.append(state_name)
 
         return a
-    
-    def endingWithOneZeroOne(self, string:str):
-        """
-        Checks whether a string ends with '101'.
 
-        :param string: The input string to check.
-        :type string: str
-        :return: True if the string ends with '101', False otherwise.
-        :rtype: bool
-        """
-        current_state = self.initial_state # By defaul initial state
+    def check_string(self, string: str):
+        current_state = self.initial_state  # By defaul initial state
 
         for s in string:
             current_state = self.input_state[current_state][s]
@@ -57,7 +49,34 @@ class DFA:
             return True
 
         return False
-    
+
+    def endingWithOneZeroOne(self, string: str):
+        """
+        Checks whether a string ends with '101'.
+
+        :param string: The input string to check.
+        :type string: str
+        :return: True if the string ends with '101', False otherwise.
+        :rtype: bool
+
+        States = 
+            ("A" , {"0": "A", "1":"B"}, initial_state = True)\n
+            ("B" , {"0": "C", "1":"B"})\n
+            ("C" , {"0": "A", "1":"D"})\n
+            ("D" , {"0": "C", "1":"B"}, final_state=True)
+
+        """
+
+        current_state = self.initial_state  # By defaul initial state
+
+        for s in string:
+            current_state = self.input_state[current_state][s]
+
+        if current_state in self.final_state:
+            return True
+
+        return False
+
     def decimalNumberDivisibleByTwo(self, string: str):
         """
         Checks whether a binary string represents a decimal number divisible by two.
@@ -66,6 +85,10 @@ class DFA:
         :type string: str
         :return: True if the binary string represents a decimal number divisible by two, False otherwise.
         :rtype: bool
+
+        States = 
+            ("A", {"0": "A", "1": "B"}, initial_state=True, final_state=True)\n
+            ("B", {"0": "A", "1": "B"})
         """
         current_state = self.initial_state  # By defaul initial state
 
@@ -96,6 +119,11 @@ class DFA:
                 if word:
                     tokens.append(word)
                     word = ""
+        
+        if word:
+            tokens.append(word)
+            word = ""
+            
         return tokens
 
     def threeConsecutiveOne(self, string: str):
@@ -106,6 +134,16 @@ class DFA:
         :type string: str
         :return: True if the string contains three consecutive ones, False otherwise.
         :rtype: bool
+
+        States = 
+            ("A" , {"0": "A", "1":"B"}, initial_state = True)\n
+            ("B" , {"0": "A", "1":"C"})\n
+            ("C" , {"0": "A", "1":"D"})\n
+            ("D" , {"0": "F", "1":"E"}, final_state=True)\n
+            ("E" , {"0": "E", "1":"E"})\n
+            ("F", {"0": "F", "1":"G"}, final_state=True)\n
+            ("G", {"0": "F", "1":"H"}, final_state=True)\n
+            ("H", {"0": "F", "1":"D"}, final_state=True)
         """
         current_state = self.initial_state  # By defaul initial state
 
@@ -116,19 +154,23 @@ class DFA:
             return True
 
         return False
-    
+
     def equalNumberOfOneZero(self, string: str):
         """
         Checks whether the given string has an equal number of 1's and 0's by traversing the DFA.
-        
+
         Args:
             string (str): The input string to check for an equal number of 1's and 0's.
-            
+
         Returns:
             bool: True if the input string has an equal number of 1's and 0's and ends in a final state,
                 False otherwise.
+
+        States = 
+            ("A", {"0": "B", "1": "B"}, initial_state=True, final_state=True)\n
+            ("B", {"0": "A", "1": "A"})
         """
-        current_state = self.initial_state # By defaul initial state
+        current_state = self.initial_state  # By defaul initial state
         count_0 = 0
         count_1 = 0
 
@@ -137,26 +179,29 @@ class DFA:
             if s == "0":
                 count_0 += 1
             if s == "1":
-                count_1 += 1 
+                count_1 += 1
             current_state = self.input_state[current_state][s]
 
         if current_state in self.final_state and count_0 == count_1:
             return True
 
         return False
-    
+
     def countNumberOfOneZero(self, string: str):
         """
         Counts the number of 1's and 0's in the given string by traversing the DFA.
-        
+
         Args:
             string (str): The input string to count the number of 1's and 0's.
-            
+
         Returns:
             str: A string indicating the number of 1's and 0's in the input string in the format 
                 "The Number of 1's is {count_1} and number of 0's is {count_0}".
+
+        States = 
+            ("A", {"0": "A", "1": "A"}, initial_state=True)
         """
-        current_state = self.initial_state # By defaul initial state
+        current_state = self.initial_state  # By defaul initial state
         count_0 = 0
         count_1 = 0
 
@@ -165,7 +210,7 @@ class DFA:
             if s == "0":
                 count_0 += 1
             if s == "1":
-                count_1 += 1 
+                count_1 += 1
             current_state = self.input_state[current_state][s]
 
         return f"The Number of 1's is {count_1} and number of 0's is {count_0}"
@@ -178,9 +223,8 @@ class DFA:
             print(key, ":", value)
 
 
-
 class TuringMachine:
-    def __init__(self, input_state = {}, initial_state = None, final_state = []):
+    def __init__(self, input_state={}, initial_state=None, final_state=[]):
         """
         Initializes a new TuringMAchine object.
 
@@ -275,10 +319,8 @@ class TuringMachine:
                 return False
 
 
-
-
 if __name__ == "__main__":
-    
+
     dfa = DFA()
     tm = TuringMachine()
 
@@ -354,5 +396,3 @@ if __name__ == "__main__":
     print(tm.turingMachineEvenOnes("1")) # False
     print(tm.turingMachineEvenOnes("1111")) # True
     '''
-
-
